@@ -20,18 +20,20 @@ import json
 import getpass
 from bs4 import BeautifulSoup as bs
 from datetime import datetime as dt
-v='2.6.97'
+v='2.8.97'
 n='civilianM'
 a='AC97'
 m='AC96'
 __all__ = ('upgrade','checkClass','wait','randint','decimal','garbledCode','pausePrint','captcha','judge',
     'hideInput','justNow','openFolder','getAddress','find','author','safe','error','myos',
-    'LibraryError','ConscienceError','ArgeementWarning','openWeb','UnknownError','whatNews')
+    'LibraryError','ConscienceError','ArgeementWarning','openWeb','UnknownError','whatNews','translate')
 #print("欢迎使用civilianM，当前版本："+v)
 def whatNews():
-    whatNew = ['2021-10-16 civilianM-2.6.97 更新日志',
+    whatNew = ['2021-10-17 civilianM-2.8.97 紧急更新日志',
         '1.readme.md有更改',
-        '2:decimal函数有改动']
+        '2.openFolder紧急维护',
+        '3.新增translate函数，他可以允许你中英文翻译',
+        '4.3.0.97版本将会于11月上旬更新，且3.0.97将会是大更新']
     for n in whatNew:
         if n == whatNew[0]:
             print(n)
@@ -47,8 +49,9 @@ def upgrade():
     r = (
             rs
             .get('https://pypi.org/project/civilianM/#history'))
-    s = bs(r.text,'lxml')
-    d = s.find_all('p',class_='release__version')
+
+    l = bs(r.text,'lxml')
+    d = l.find_all('p',class_='release__version')
     for nn in d:
         ev = nn.text.strip()
         dd.append(ev)
@@ -90,6 +93,16 @@ def checkClass(objects,need):
         raise AttributeError(
             "无效参数"+str(need))
 
+def translate(string):
+    #CE:Chinese to English
+    pr = {'doctype':'json', 'type':'AUTO', 'i':str(string)}
+    r = (
+        rs
+        .get('http://fanyi.youdao.com/translate',params=pr))
+    r2c = r.json()
+    re = r2c['translateResult'][0][0]["tgt"]
+    return string + ' -----> ' + re
+
 #Sleep
 def wait(t):
     """功能：让程序睡眠
@@ -218,11 +231,9 @@ def openFolder(fn=None):
     def efve():
         key = winreg.OpenKey(winreg.HKEY_CURRENT_USER, r'Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders')
         return winreg.QueryValueEx(key, "Desktop")[0] + "/"
-    if fn==None:
-        nh = efve() + 'example'
     if fn:
         nh = efve() + fn
-    if not os.path.exists(nh):
+        if not os.path.exists(nh):
             os.mkdir(nh)
     else:
         nh = os.getcwd()
@@ -257,7 +268,11 @@ def getAddress():
           'computer':{'name':comp,'computerIP':comip}}
     return nr
 
-def openWeb(website):
+def openWeb(website,sec=False):
+    if sec:
+        website = 'https://'+website
+    elif sec==False:
+        website = 'http://' +website
     webbrowser.open(website)
 
 gr = []
